[Suggested description]
A buffer overflow in os/net/mac/ble/ble-l2cap.c in the BLE stack in Contiki-NG 4.4 and earlier
allows an attacker to execute arbitrary code via malicious L2CAP frames.

------------------------------------------

[Additional Information]
# Bug Description
While decoding L2CAP fragments, no bounds checking is performed on the
user-provided 2-byte length field. Reading the length field is
followed by a call to memcpy with user-specified size.

# Source Code References
- input_l2cap_frame_flow_channel: https://github.com/contiki-ng/contiki-ng/blob/release/v4.4/os/net/mac/ble/ble-l2cap.c#L428

First fragment

    /* handle first fragment */
    memcpy(&frame_len, &data[0], 2);
    memcpy(&channel-rx_buffer.sdu_length, &data[4], 2);
    payload_len = frame_len - 2;

    memcpy(channel-rx_buffer.sdu, &data[6], payload_len);
    channel-rx_buffer.current_index = payload_len;


Subsequent fragments

    /* subsequent fragment */
    memcpy(&frame_len, &data[0], 2);
    payload_len = frame_len;

    memcpy(&channel-rx_buffer.sdu[channel-rx_buffer.current_index], &data[4], payload_len);
    channel-rx_buffer.current_index += payload_len;
``

# Impact
Out of bounds write into data section via crafted BLE packets leading to Remote Code Execution (RCE) on the target device.

# Exploitability
Fuzzing inputs have been found which fully control the program
counter. This can be achieved by abusing the overflow into global
variables in the data section.

------------------------------------------

[Vulnerability Type]
Buffer Overflow

------------------------------------------

[Vendor of Product]
Contiki-NG

------------------------------------------

[Affected Product Code Base]
Contiki-NG - 4.4 and earlier

------------------------------------------

[Affected Component]
Bluetooth Low Energy Network Stack

------------------------------------------

[Attack Type]
Remote

------------------------------------------

[Impact Code execution]
true

------------------------------------------

[Attack Vectors]
By sending a malicious L2CAP payload

------------------------------------------

[Reference]
-anonymized-

------------------------------------------

[Has vendor confirmed or acknowledged the vulnerability?]
true

------------------------------------------

[Discoverer]
-anonymized-

Use CVE-2020-BLINDED.
