# Analyzing the Crash
The crash occurs in ieee802154_reassemble at pc=0x00403a72, while operating on a packet with a NULL pkt->buffer pointer.

## Interactive Bug Triaging with known Bug
To interactively see this, set a breakpoint at `0x40D154` and observe the value of `mpdu.mhr.fs->fc.frame_type`, which is stored in register `r3` while hitting that code location.

```
./run.sh -b 0x40D154
```

Here we are looking for a value of type `IEEE802154_FRAME_TYPE_ACK`, which corresponds to the numeric value `2`:

```
ipdb> uc.regs.r3
0x2
```

As more deeply described in the bug report, this causes a non-handled fall-through case to be hit, which results in a later NULL pointer de-reference.

## Trace-based Bug Triaging without known Bug
To analyze the crash without knowing the bug a-priory, we can also follow the memory write log to find the initial corruption. We first pipe the full log into a file:

```
./run.sh > log.txt
```

Inspecting the trace, we first see the crash cause:

```
Basic Block: addr= 0x0000000000403a70 (lr=0x40d209)
        >>> Read: addr= 0x0000000020107d38 size=4 data=0x00000000 (pc 0x00403a70)
        >>> [ 0x00403a72 ] INVALID READ: addr= 0x0000000000000000 size=1 data=0x0000000000000000
Execution failed with error code: 6 -> Invalid memory read (UC_ERR_READ_UNMAPPED)
```

This corresponds to the folllowing piece of pseudo code:
```
net_verdict __fastcall ieee802154_reassemble(net_pkt *pkt) {
  if ( !pkt || (frags = pkt->_anon_1.frags) == 0 )
  {
    v3 = "Nothing to reassemble";
    log_0(v3, (log_msg_ids)961);
    return 2;
  }
  data = frags->_anon_1._anon_0.data;
  v5 = *data;
```

As we can see, de-referencing the `data` variable leads to a NULL pointer de-reference. This occurs due to a corrupted packet structure being passed from ieee802154_recv.

From here, backtracking eventually leads to the discovery of the missing handling of the `IEEE802154_FRAME_TYPE_ACK` packet type.

A more comprehensive writeup of how to identify the actual issue is TODO.