# Analyzing the Crash
The crash occurs in ieee802154_reassemble at pc=0x00403a72, while operating on a packet with a NULL pkt->buffer pointer.

## Trace-based Bug Triaging without known Bug
To analyze the crash without knowing the bug a-priory, we first pipe the full log into a file:

```
./run.sh > log.txt
```

Inspecting the trace, we first see the crash cause:

```
Calling function: net_6lo_uncompress
...
Basic Block: addr= 0x0000000000406c74 (lr=0x403bb3)
        >>> Write: addr= 0x20104f88[SP:+0028] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104f8c[SP:+0024] size=4 data=0x201023b0 (pc 0x00406c74)
        >>> Write: addr= 0x20104f90[SP:+0020] size=4 data=0x201073c4 (pc 0x00406c74)
        >>> Write: addr= 0x20104f94[SP:+001c] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104f98[SP:+0018] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104f9c[SP:+0014] size=4 data=0x000080ff (pc 0x00406c74)
        >>> Write: addr= 0x20104fa0[SP:+0010] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104fa4[SP:+000c] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104fa8[SP:+0008] size=4 data=0x00000000 (pc 0x00406c74)
        >>> Write: addr= 0x20104fac[SP:+0004] size=4 data=0x00403bb3 (pc 0x00406c74)
        >>> Read: addr= 0x00000000201073d4 size=4 data=0x00000000 (pc 0x00406c78)
        >>> [ 0x00406c7a ] INVALID READ: addr= 0x0000000000000008 size=4 data=0x0000000000000000
Execution failed with error code: 6 -> Invalid memory read (UC_ERR_READ_UNMAPPED)
```

At this location we find the following assembler code:
```
text:00406C74                 PUSH.W  {R3-R11,LR}
text:00406C78                 LDR     R6, [pkt,#0x10]
text:00406C7A                 LDR     R4, [R6,#8]
```

This corresponds to the folllowing piece of pseudo code:
```
  frags = pkt->_anon_1.frags;
  data = frags->_anon_1._anon_0.data;
```

As we can see, de-referencing the `frags` variable leads to a NULL pointer de-reference (with an 8-byte offset). This occurs due to a corrupted packet structure being passed to `net_6lo_uncompress` from `ieee802154_reassemble`.

From here, backtracking eventually leads to finding out that a radio frame is inserted which is marked for fragmentation, but itself contains the full payload size, leading to an unexpected pointer alias, which results in an unexpected NULL pointer assignment.

A more comprehensive writeup of how to identify the actual issue is TODO.